NativeUnicodeCodec class

Inheritance
Available extensions

Constructors

NativeUnicodeCodec()
const

Properties

decoder Converter<List<int>, String>
Returns the decoder of this, converting from List<int> to String.
final
encoder Converter<String, List<int>>
Returns the encoder from String to List<int>.
final
hashCode int
The hash code for this object.
no setterinherited
inverted Codec<List<int>, String>
Inverts this.
no setterinherited
name String
Name of the encoding.
final
renamedUC Encoding

Available on E, provided by the RenamedEncodingExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(List<int> encoded) String
Decodes encoded data.
inherited
decodeStream(Stream<List<int>> byteStream) Future<String>
inherited
encode(String input) List<int>
Encodes input.
inherited
fuse<R>(Codec<List<int>, R> other) Codec<String, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renamed(String name) Encoding

Available on E, provided by the RenamedEncodingExt extension

renamedBy(StrConv renameRule) Encoding

Available on E, provided by the RenamedEncodingExt extension

renamedUCBy(StrConv renameRule) Encoding

Available on E, provided by the RenamedEncodingExt extension

renamedUCTo(String name) Encoding

Available on E, provided by the RenamedEncodingExt extension

toString() String
A string representation of this object.
inherited
withByteOrder({ByteOrder order = ByteOrder.be, bool addBom = false}) Encoding

Available on Encoding, provided by the WithByteOrder extension

Operators

operator ==(Object other) bool
The equality operator.
inherited