EncodingTab class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String key, Encoding encoding, {List<String> alt = const <String>[], String? group, String? series, int? nr, String? variant, int remains = 0}) → void
hasKey(String key) bool
list([bool useCounter = false]) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showList([bool useCounter = false]) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dflt EncodingTab
no setter