Manager class

Constructors

Manager(EncodingTab tab)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fenceIndexes(List<String> argsOf) List<int>
getFences(List<String> argsOf) List<Fence>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printAs(List<MassageLine> res, {bool debug = false}) → void
process(List<String> argsOf) List<MassageLine>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

re RegExp
getter/setter pair