ErrorHandleConv<S, T, E extends Object> class
- Inheritance
- Available extensions
Constructors
-
ErrorHandleConv(Converter<
S, T> underlying, OnError<E, T> onError)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onError
→ OnError<
E, T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
underlying
→ Converter<
S, T> -
final
Methods
-
asListFuse(
) → Converter< R, List< S> > -
Available on Converter<
R, S> , provided by the AsListConvFuse extension -
bind(
Stream< S> stream) → Stream<T> -
Transforms the provided
stream.inherited -
cast<
RS, RT> () → Converter< RS, RT> -
Provides a
Converter<RS, RT>view of this stream transformer.inherited -
convert(
S src) → T -
Converts
inputand returns the result of the conversion.override -
fuse<
TT> (Converter< T, TT> other) → Converter<S, TT> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startChunkedConversion(
Sink< T> sink) → Sink<S> -
Starts a chunked conversion.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited