EncodingTabRec class
- Implemented types
- Available extensions
Constructors
Properties
-
alt
→ List<
String> -
Alternative Names for the Encoding
final
- encoding → Encoding
-
final
- group → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iana → String
-
no setter
- key → String
-
final
- nr → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- series → String?
-
final
- shows → String
-
no setter
- variant → String?
-
final
Methods
-
asListView(
{int counter()?, int? allCount, required int tabCount(String key)}) → String -
compareTo(
EncodingTabRec other) → int -
Compares this object to another object.
override
-
compareTo(
EncodingTabRec other) → int -
Available on EncodingTabRec, provided by the ComparableSppl extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited