compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(EncodingTabRec other){
late int cnt;
// group > series > (nr | variant) > key > encoding.name
// non- null > null
cnt = this.group.compareTo(other.group);
if(cnt != 0) return cnt;
cnt = this.series.compareTo(other.series);
if(cnt != 0) return cnt;
cnt = this.group.compareTo(other.group);
if(cnt != 0) return cnt;
cnt = this.nr.compareTo(other.nr);
if(cnt != 0) return cnt;
cnt = this.variant.compareTo(other.variant);
if(cnt != 0) return cnt;
return this.iana.compareTo(other.iana);
}